@@ -40,7 +40,7 @@ def _parse_help(state, _, args, time):
         '     add a new item in todo state',
         '     use addp/addd to add an item in progress/done status',
         '     use addt to add an item on top of the backlog',
-        '  [white edit] [gray [[NUM]]]',
+        '  [white edit] [gray \\[NUM\\]]',
         '     edit current item/NUM',
         '  [white status]',
         '      display current item',
@@ -48,17 +48,17 @@ def _parse_help(state, _, args, time):
         '      show in-progress and todo items',
         '  [white all]',
         '      show all items',
-        '  [white standup] [gray [[DAYS]]]',
+        '  [white standup] [gray \\[DAYS\\]]',
         '      show items suitable for daily standup',
-        '  [white start] [gray [[NUM]]]',
+        '  [white start] [gray \\[NUM\\]]',
         '      start progress on current item/NUM',
-        '  [white done] [gray [[NUM]]]',
+        '  [white done] [gray \\[NUM\\]]',
         '      mark current item/NUM done',
-        '  [white blocked] [gray [[NUM]]]',
+        '  [white blocked] [gray \\[NUM\\]]',
         '      mark current item/NUM as blocked',
-        '  [white delete] [gray [[NUM]]]',
+        '  [white delete] [gray \\[NUM\\]]',
         '      mark current item/NUM as deleted',
-        '  [white todo] [gray [[NUM]]]',
+        '  [white todo] [gray \\[NUM\\]]',
         '      mark current/NUM as todo',
         '  [white order]',
         '      re-order todo items',
